mapping = {
    'BigIntegerField': 'long',
    'AutoField': 'integer',
    'BigAutoField': 'long',
    'BooleanField': 'boolean',
    'DateTimeField': 'date',
    'DateField': 'date',
    'FloatField': 'float',
    'IntegerField': 'integer',
    'TextField': 'text',
    'URLField': 'text',
    'CharField': 'text',
    'TimeField': 'date',
    'SmallAutoField': 'short',
    'SmallIntegerField': 'short',
    'DOUBLE': 'double',
    'DecimalField': 'scaled_float',
    'EmailField': 'text',
    'IPAddressField': 'text',
    'SlugField': 'text',
    'PositiveBigIntegerField': 'long',
    'PositiveIntegerField': 'integer',
    'PositiveSmallIntegerField': 'short',
    'FilePathField': 'text',
    'CommaSeparatedIntegerField': 'numeric',
}
